@@ -1,9 +1,13 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
+import typing
 from suanpan import g
 from suanpan.proxy import Proxy
 
+if typing.TYPE_CHECKING:
+    from suanpan.types import AppT
+
 
 class App(Proxy):
     MAPPING = {
@@ -29,4 +33,4 @@ class App(Proxy):
 
 
 TYPE = g.appType
-app = App(type=TYPE)
+app: 'AppT' = App(type=TYPE)
